#!/bin/sh

# Copyright (c) 2016 Samsung Electronics Co., Ltd All Rights Reserved
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# Script used to flash, prepare and configure ODROID U3
#
# Syntax is: odroid_prepare_conf_flash.sh $SDMUX $BOOT_IMAGE $IMAGE \
#    [$NATIVE_TCT_REPO]
#
# Author: Aleksander Mistewicz <a.mistewicz@samsung.com>

export TESTLAB_SCRIPTS="$(CDPATH='' cd -- "$(dirname -- "$0")" && pwd -P)"

. "${TESTLAB_SCRIPTS}/common.sh"

SDMUX="$1"
BOOT_IMAGE="$2"
IMAGE="$3"
NATIVE_TCT_REPO="$4"

test -n "${SDMUX}" || die "Missing argument: sdmux!"
test -n "${BOOT_IMAGE}" || die "Missing argument: boot image!"
test -n "${IMAGE}" || die "Missing argument: image!"

. "${TESTLAB_SCRIPTS}/prepare/prepare.sh"
. "${TESTLAB_SCRIPTS}/flash/flash.sh"

echo "### prepare ###"

IMAGE_UNPACKED="/tmp/image_unpacked_${SDMUX}"
IMAGE_MOUNTPOINT="/tmp/image_mounted_${SDMUX}"

switch2testserver "${SDMUX}"

unpack_image "${BOOT_IMAGE}" "${IMAGE}" "${IMAGE_UNPACKED}"

mount_image "${IMAGE_UNPACKED}/rootfs.img" "${IMAGE_MOUNTPOINT}"
mount_image "${IMAGE_UNPACKED}/system-data.img" "${IMAGE_MOUNTPOINT}/opt"
mount_image "${IMAGE_UNPACKED}/user.img" "${IMAGE_MOUNTPOINT}/opt/usr"
sudo sed -i '/RemainAfterExit=yes/d' "${IMAGE_MOUNTPOINT}/usr/lib/systemd/system/tizen-system-env.service"
install_iserial "${SDMUX}" "${IMAGE_MOUNTPOINT}"
set_usb_mode "${IMAGE_MOUNTPOINT}"
install_hdmi_force "${IMAGE_MOUNTPOINT}"
unmount_image "${IMAGE_MOUNTPOINT}/opt/usr"
unmount_image "${IMAGE_MOUNTPOINT}/opt"
unmount_image "${IMAGE_MOUNTPOINT}"

echo "### flash ###"

UUID_FILE="/var/tmp/uuid-${SDMUX}"
DEV_SDCARD=$(uuid2dev "${UUID_FILE}" "${SDMUX}") || die "sdcard not found!"

cd "${IMAGE_UNPACKED}"
"${TESTLAB_SCRIPTS}/flash/flash_dd.sh" "${DEV_SDCARD}"
RET=$?
cd "${OLDPWD}"

change_uuid "${UUID_FILE}" "${DEV_SDCARD}"
if [ $RET -ne 0 ]; then
    die "flash_dd exited with an error" "$RET"
fi
switch2device "${SDMUX}"
restart_device "${SDMUX}"

echo "### cleanup ###"

rm -rf "${IMAGE_MOUNTPOINT}"
rm -rf "${IMAGE_UNPACKED}"
