#!/bin/sh

# Copyright (c) 2016-2017 Samsung Electronics Co., Ltd All Rights Reserved
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# Script used to flash, prepare and configure RPI 3
#
# Syntax is: odroid_prepare_conf_flash.sh $SDMUX $BOOT_IMAGE $IMAGE \
#    [$NATIVE_TCT_REPO]
#
# Author: Aleksander Mistewicz <a.mistewicz@samsung.com>

export TESTLAB_SCRIPTS="$(CDPATH='' cd -- "$(dirname -- "$0")" && pwd -P)"

. "${TESTLAB_SCRIPTS}/common.sh"

SDMUX="$1"
BOOT_IMAGE="$2"
IMAGE="$3"

test -n "${SDMUX}" || die "Missing argument: sdmux!"
test -n "${BOOT_IMAGE}" || die "Missing argument: boot image!"
test -n "${IMAGE}" || die "Missing argument: image!"

. "${TESTLAB_SCRIPTS}/prepare/prepare.sh"
. "${TESTLAB_SCRIPTS}/flash/flash.sh"

echo "### prepare ###"

IMAGE_UNPACKED="/tmp/image_unpacked_${SDMUX}"
IMAGE_MOUNTPOINT="/tmp/image_mounted_${SDMUX}"

switch2testserver "${SDMUX}"

unpack_image "${BOOT_IMAGE}" "${IMAGE}" "${IMAGE_UNPACKED}"

echo "### flash ###"

UUID_FILE="/var/tmp/uuid-${SDMUX}"
DEV_SDCARD=$(uuid2dev "${UUID_FILE}" "${SDMUX}") || die "sdcard not found!"

cd "${IMAGE_UNPACKED}"
case "$IMAGE" in
    *2parts*)
        "${TESTLAB_SCRIPTS}/flash/flash_dd_rpi3-2parts.sh" "${DEV_SDCARD}"
        ;;
    *)
        "${TESTLAB_SCRIPTS}/flash/flash_dd_rpi3.sh" "${DEV_SDCARD}"
        ;;
esac
RET=$?
cd "${OLDPWD}"

change_uuid "${UUID_FILE}" "${DEV_SDCARD}"
if [ $RET -ne 0 ]; then
    die "flash_dd exited with an error" "$RET"
fi
switch2device "${SDMUX}"
restart_device "${SDMUX}"
